#
# spec file for package nodejs6
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


###########################################################
#
#   WARNING! WARNING! WARNING! WARNING! WARNING! WARNING!
#
# This spec file is generated from a template hosted at
# https://github.com/AdamMajer/nodejs-packaging
#
###########################################################

Name:           nodejs6
Version:        6.12.3
Release:        1.1

%define node_version_number 6

%if 0%{?suse_version} == 1110
%define _libexecdir %{_exec_prefix}/lib
%endif

# Only Leap 42.2+, SLE 12 SP2+ and Tumbleweed have OpenSSL 1.0.2.
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%bcond_with    intree_openssl
%else
%bcond_without intree_openssl
%endif

%if 0%{suse_version} >= 1330
%bcond_with    intree_cares
%else
%bcond_without intree_cares
%endif

%if 0%{?suse_version} >= 1200
%bcond_with    intree_icu
%else
%bcond_without intree_icu
%endif

%ifarch aarch64 ppc ppc64 ppc64le s390 s390x
%bcond_with    gdb
%else
%bcond_without gdb
%endif

# No binutils_gold on SLE 12 GA (aarch64).
%ifarch aarch64
%if 0%{?sle_version} >= 120100 || 0%{?is_opensuse}
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # aarch64

# No binutils_gold on all versions of SLE 12 and Leap 42 (s390x).
%ifarch s390x s390
%if 0%{?suse_version} > 1320
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # s390x s390

%ifnarch aarch64 s390x s390
%bcond_without binutils_gold
%endif

Summary:        Evented I/O for V8 JavaScript
License:        MIT
Group:          Development/Languages/NodeJS
Url:            https://nodejs.org
Source:         https://nodejs.org/dist/v%{version}/node-v%{version}.tar.xz
Source1:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt
Source2:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt.sig
Source3:        nodejs.keyring

## UPSTREAM PATCHES HERE, if any
Patch3:         fix_ci_tests.patch

## Our patches
# PATCH-FIX-OPENSUSE -- set correct path for dtrace if it is built
Patch101:       nodejs-libpath.patch
# PATCH-FIX-UPSTREAM -- use custom addon.gypi by default instead of
# downloading node source
Patch102:       node-gyp-addon-gypi.patch
# PATCH-FIX-SLE -- configure script uses Python check_output method
# which isn't included in Python 2.6 (used in SLE 11).
Patch103:       nodejs-sle11-python26-check_output.patch
# PATCH-FIX-OPENSUSE -- install user global npm packages to /usr/local
# instead of /usr
Patch104:       npm_search_paths.patch

# Use versioned binaries and paths
Patch200:       versioned.patch

%if %{with binutils_gold}
BuildRequires:  binutils-gold
%endif

# Node.js 4/6/7 requires GCC 4.8.5+.
#
# For Node.js 8.x, upstream requires GCC 4.9.4+, as GCC 4.8 may have
# slightly buggy C++11 support: https://github.com/nodejs/node/pull/13466
#
# If the default compiler is not supported, use the most recent compiler
# version available.
%if 0%{?suse_version} == 1110
# GCC 5 is only available in the SUSE:SLE-11:SP4:Update repository (SDK).
%if %node_version_number >= 8
BuildRequires:  gcc5-c++
%define cc_exec  gcc-5
%define cpp_exec g++-5
%else
BuildRequires:  gcc48-c++
%define cc_exec  gcc-4.8
%define cpp_exec g++-4.8
%endif # node >= 8
%endif # sles == 11

# SLE 12 and Leap 42
# GCC 6 is only available with SLE 12 SP1 and Leap 42.2+.
%if %node_version_number >= 8 && 0%{?suse_version} == 1315
%if 0%{?sle_version} < 120100
BuildRequires:  gcc5-c++
%define cc_exec  gcc-5
%define cpp_exec g++-5
%else
BuildRequires:  gcc6-c++
%define cc_exec  gcc-6
%define cpp_exec g++-6
%endif # SLE 12 < SP1
%endif # node >= 8 and sle == 12

# No special version defined, use default.
%if ! 0%{?cc_exec:1}
BuildRequires:  gcc-c++
%endif

BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  python
BuildRequires:  xz
BuildRequires:  zlib-devel

%if ! %{with intree_openssl}

%if %node_version_number >= 8
BuildRequires:  openssl-devel >= 1.0.2
%else # older node doesn't support OpenSSL 1.1

%if 0%{?suse_version} >= 1330
BuildRequires:  libopenssl-1_0_0-devel
%else
BuildRequires:  openssl-devel >= 1.0.2
%endif

%endif # older node doesn't support OpenSSL 1.1
%endif # ! {with intree_openssl}

%if ! %{with intree_cares}
BuildRequires:  pkgconfig(libcares) >= 1.10.0
%endif

%if ! %{with intree_icu}
BuildRequires:  pkgconfig(icu-i18n) >= 52
%endif

Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     npm(npm) = 3.10.10

#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
%global nodejs_abi 6.0
Provides:       nodejs(abi) = %{nodejs_abi}

#this corresponds to the "engine" requirement in package.json
Provides:       nodejs(engine) = %{version}

# Multiple versions of NodeJS can be installed at a time, but
# to properly allow correct version execution from 3rd party
# npm software, `env node` requires further help than only
# update-alternatives can provide.
Provides:       nodejs = %{version}
Requires:       nodejs-common

# For SLE11, to be able to use the certificate store we need to have properly
# symlinked certificates. The compatability symlinks are provided by the
# openssl1 library in the Security Module
%if 0%{?suse_version} == 1110
Requires:       openssl1
%endif

# Building Node.js only makes sense on V8 architectures.
ExclusiveArch:  %{ix86} x86_64 armv7hl aarch64 ppc ppc64 ppc64le s390 s390x
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Node.js is a JavaScript runtime built on Chrome's V8 JavaScript engine.
Node.js uses an event-driven, non-blocking I/O model that makes it
lightweight and efficient. Node.js' package ecosystem, npm, is the largest
ecosystem of open source libraries in the world.

%package devel
Summary:        Files needed for development of NodeJS platforms
Group:          Development/Languages/NodeJS
Provides:       nodejs-devel = %{version}
Requires:       %{name} = %{version}

%description devel
This package provides development headers for Node.js.

%package -n npm6
Summary:        Package manager for Node.js
Group:          Development/Languages/NodeJS
Requires:       %{name}-devel = %{version}
Provides:       nodejs-npm = %{version}
Obsoletes:      nodejs-npm < 4.0.0
Provides:       npm = %{version}
Provides:       npm(npm) = 3.10.10

%description -n npm6
A package manager for Node.js that allows developers to install and
publish packages to a package registry.

%package docs
Summary:        Node.js API documentation
Group:          Documentation/Other
%if 0%{?suse_version} >= 1200
# using noarch subpackage seems to break debuginfo on older releases
BuildArch:      noarch
%endif

%description docs
The API documentation for the Node.js JavaScript runtime.

%prep
echo "`grep node-v%{version}.tar.xz %{S:1} | head -n1 | cut -c1-64`  %{S:0}" | sha256sum -c
%setup -q -n node-v%{version}
%patch3 -p1
%if ! %{with intree_openssl}
%endif
%patch101 -p1
%patch102 -p1
# Add check_output to configure script (not part of Python 2.6 in SLE11).
%if 0%{?suse_version} == 1110
%patch103 -p1
%endif
%patch104 -p1
%patch200 -p1

# Make sure nothing gets included from bundled deps:
# We only delete the source and header files, because
# the remaining build scripts are still used.
%if ! %{with intree_openssl}
find deps/openssl -name *.[ch] -delete
%endif

%if ! %{with intree_icu}
rm -rf deps/icu-small
%endif

%if ! %{with intree_cares}
find deps/cares -name *.[ch] -delete
%endif

find deps/zlib -name *.[ch] -delete

# Annoying, over-repetitive patch updated just because lines in
# documentation changes every version.
find -name *.md.orig -delete

%build
# percent-configure pulls in something that confuses node's configure
# script, so we'll do it thus:
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

# Node.js 4.x does not include the ICU database in the source tarball.
%define has_small_icu %(test -d "deps/icu-small" && echo 1 || echo 0)

./configure \
    --prefix=%{_prefix} \
%if ! %{with intree_openssl}
    --shared-openssl \
%endif
    --shared-zlib \
%if ! %{with intree_cares}
    --shared-cares \
%endif
%if ! %{with intree_icu}
    --with-intl=system-icu \
%else
%if %{has_small_icu}
    --with-intl=small-icu \
    --with-icu-source=deps/icu-small \
%endif
%endif
%if %{with gdb}
    --gdb \
%endif
    --without-dtrace \
    --openssl-use-def-ca-store

make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}
rm %{buildroot}%{_datadir}/doc/node/gdbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldb_commands.py

# remove .bak files, if any
find %{buildroot} -name \*.bak -print -delete

# npm man page
install -D -m 644 deps/npm/man/man1/npm.1 %{buildroot}%{_mandir}/man1/npm%{node_version_number}.1

#node-gyp needs common.gypi too
install -D -m 644 common.gypi \
	%{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/common.gypi
#       %%{buildroot}%%{_datadir}/node/common.gypi
# install addon-rpm.gypi
install -D -m 644 addon-rpm.gypi \
       %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/addon-rpm.gypi

# clean
# hidden files and directories
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name ".*" -print0 | xargs -r0 -0 rm -rf --
# windows stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.bat" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.cmd" -delete
# build stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "Makefile" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/{test,scripts}
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*.sh" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/src
# remove examples/tests/benchmark stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "example*" -print0 | xargs -0 rm -rf --
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/NODE_MODULES -name "test*" -print0 | xargs -0 rm -rf --
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*_test.*" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -type d -name "benchmark" -print0 | xargs -0 rm -rf --

# fix permissions
find %{buildroot}%{_libdir}/node_modules -type f -exec chmod -x {} +
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/np*-cli.js
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/node-gyp-bin/node-gyp
# browser.js is useless for npm cli
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "browser.js" -delete

# file duplicates
%fdupes %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}
%fdupes %{buildroot}%{_includedir}/node%{node_version_number}

# Update alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f node-default     %{buildroot}%{_sysconfdir}/alternatives/node-default
ln -s -f node.1%{ext_man} %{buildroot}%{_sysconfdir}/alternatives/node.1%{ext_man}
ln -s -f npm-default      %{buildroot}%{_sysconfdir}/alternatives/npm-default
ln -s -f npm.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npm.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/node-default         %{buildroot}%{_bindir}/node-default
ln -s %{_sysconfdir}/alternatives/node.1%{ext_man}     %{buildroot}%{_mandir}/man1/node.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npm-default          %{buildroot}%{_bindir}/npm-default
ln -s %{_sysconfdir}/alternatives/npm.1%{ext_man}      %{buildroot}%{_mandir}/man1/npm.1%{ext_man}
%if %{node_version_number} >= 8
ln -s -f npx-default      %{buildroot}%{_sysconfdir}/alternatives/npx-default
ln -s -f npx.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npx.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npx-default          %{buildroot}%{_bindir}/npx-default
ln -s %{_sysconfdir}/alternatives/npx.1%{ext_man}      %{buildroot}%{_mandir}/man1/npx.1%{ext_man}
%endif

%check
ln addon-rpm.gypi deps/npm/node_modules/node-gyp/addon-rpm.gypi
# Tarball doesn't have eslint package distributed, so disable some tests
find test -name \*-eslint-\* -print -delete
# No documentation is generated, don't bother checking it
rm -f test/doctool/test-make-doc.js
# DNS lookup doesn't work in build root
rm -f test/parallel/test-dns-cancel-reverse-lookup.js \
      test/parallel/test-dns-resolveany.js
# multicast test fail since no socket?
rm -f test/parallel/test-dgram-membership.js
# Run CI tests - 'advisory for now'
make test-ci || echo "****** UNIT TESTS NOT ALL HAPPY *****"

%files
%defattr(-, root, root)
%doc AUTHORS LICENSE *.md
%doc deps/v8/tools/gdbinit
%dir %{_libdir}/node_modules
%{_bindir}/node%{node_version_number}
%{_mandir}/man1/node%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/node-default
%ghost %{_mandir}/man1/node.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/node-default
%ghost %{_sysconfdir}/alternatives/node.1%{ext_man}
%exclude %{_libdir}/node_modules/npm%{node_version_number}

%files -n npm%{node_version_number}
%defattr(-, root, root)
%{_bindir}/npm%{node_version_number}
%{_libdir}/node_modules/npm%{node_version_number}
%{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npm-default
%ghost %{_mandir}/man1/npm.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npm-default
%ghost %{_sysconfdir}/alternatives/npm.1%{ext_man}

%if %{node_version_number} >= 8
%{_bindir}/npx%{node_version_number}
%ghost %{_bindir}/npx-default
%ghost %{_mandir}/man1/npx.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npx-default
%ghost %{_sysconfdir}/alternatives/npx.1%{ext_man}
%endif

%files devel
%defattr(-, root, root)
%{_includedir}/node%{node_version_number}
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/node%{node_version_number}.stp

%files docs
%defattr(-,root,root)
%doc doc/api

%post
update-alternatives \
        --install %{_bindir}/node-default node-default %{_bindir}/node%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/node.1%{ext_man} node.1%{ext_man} %{_mandir}/man1/node%{node_version_number}.1%{ext_man}

%postun
if [ ! -f %{_bindir}/node%{node_version_number} ] ; then
    update-alternatives --remove node-default %{_bindir}/node%{node_version_number}
fi

%post -n npm%{node_version_number}
update-alternatives \
        --install %{_bindir}/npm-default npm-default %{_bindir}/npm%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npm.1%{ext_man} npm.1%{ext_man} %{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%if %{node_version_number} >= 8
update-alternatives \
        --install %{_bindir}/npx-default npx-default %{_bindir}/npx%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npx.1%{ext_man} npx.1%{ext_man} %{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%endif

%postun -n npm%{node_version_number}
if [ ! -f %{_bindir}/npm%{node_version_number} ] ; then
    update-alternatives --remove npm-default %{_bindir}/npm%{node_version_number}
fi
%if %{node_version_number} >= 8
if [ ! -f %{_bindir}/npx%{node_version_number} ] ; then
    update-alternatives --remove npx-default %{_bindir}/npx%{node_version_number}
fi
%endif

%changelog
* Tue Jan  9 2018 adam.majer@suse.de
- New upstream LTS release 6.12.3:
  * v8: profiler-related fixes
  * mostly documentation and test related changes
- nodejs-sle11-python26-check_output.patch: refreshed
* Fri Dec 22 2017 adam.majer@suse.de
- Enable CI tests in %%check target
  + fix_ci_tests.patch:
  - DNS queries in buildroots are failing with EAI_AGAIN
  - disable test-module-loading-globalpaths.js - we have
    hardcoded global paths
  + versioned.patch: call versioned node binary for tests
* Thu Dec 14 2017 adam.majer@suse.de
- Dropped 8334.diff - no longer needed
* Sat Dec  9 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.12.2:
  * deps/openssl: updated to 1.0.2n (only applies to SLE 12 SP1
    and lower) (bsc#1072322)
    [ CVE-2017-3738 CVE-2017-15896 ]
- Changes in 6.12.1:
  * build: fix npm install with --shared
    [ gh#nodejs/node#16438 ]
  * build: building on systems with default Python 3 is now
    supported
    [ gh#nodejs/node#16058 ]
  * src: v8 options can be specified with either '_' or '-' in
    NODE_OPTIONS
    [ gh#nodejs/node#14093 ]
- Remove unnecessary curl BuildRequires
- Enable gold linker on s390x (TW and SLE/Leap 15)
- Build with bundled ICU if system ICU not available (only applies
  to SLE 11)
* Wed Nov 29 2017 qantas94heavy@gmail.com
- Change BuildRequires from openssl-devel to libopenssl-1_0_0-devel
  due to Tumbleweed/Leap 15 change to OpenSSL 1.1.0 as default
* Thu Nov 16 2017 adam.majer@suse.de
- Update nodejs.keyring based on current Release Team as found on
  https://github.com/nodejs/node#release-team
* Mon Nov 13 2017 adam.majer@suse.de
- Fix permissions of node-gyp. This should be executable to allow
  building of binary node modules.
* Mon Nov 13 2017 adam.majer@suse.de
- New upstream LTS release 6.12.0:
  * assert: assert.fail() can now take one or two arguments
  * crypto: add sign/verify support for RSASSA-PSS
  * deps:
    + upgrade openssl sources to 1.0.2m
    [OpenSSL Security Advisory (bsc#1066242, bsc#1056058)
    CVE-2017-3735 CVE-2017-3736]
    + upgrade libuv to 1.15.0
  * fs: Add support for fs.write/fs.writeSync(fd, buffer, cb) and
    fs.write/fs.writeSync(fd, buffer, offset, cb) as documented
  * inspector: enable --inspect-brk
  * process: add --redirect-warnings command line argument
  * src:
    + allow CLI args in env with NODE_OPTIONS
    + --abort-on-uncaught-exception in NODE_OPTIONS
    + allow --tls-cipher-list in NODE_OPTIONS
    + use SafeGetenv() for NODE_REDIRECT_WARNINGS
  * test: remove common.fail()
- 0f3e69db.patch, icu59.patch: removed empty patches
- nodejs-libpath.patch: refreshed
* Wed Oct 25 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.11.5:
  * zlib: (CVE-2017-14919: only affects TW) In zlib v1.2.9, a
    change was made that causes an exception to be thrown when a
    raw deflate stream is initialized with windowBits set to 8.
    Node.js will now gracefully set windowBits to 9 (replicating
    the legacy behavior) to avoid a DOS vector.
* Thu Oct 19 2017 adam.majer@suse.de
- Replace {{node_version_major}} with RPM define %%node_version_number
  for simpler spec file review.
- Make sure npm program remains executable
* Wed Oct  4 2017 adam.majer@suse.de
- New upstream LTS release 6.11.4:
  * net: support passing undefined to listen() to match behavior in
  v4.x and v8.x
* Mon Sep 11 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.11.3:
  * deps: Snapshots are turned back on!!! (#14385)
  * path: win32 volume-relative paths are working again! (#14440)
  * tools: v6.x can now build with ICU 59 (#12078)
- Drop icu59.patch: merged upstream.
- Refresh versioned.patch
* Thu Aug 17 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.11.2
  * configure: add mips64el to valid_arch (#13620)
  * crypto: updated root certificates based on NSS 3.30
    (#13279, #12402)
  * deps: upgrade OpenSSL to version 1.0.2.l (#12913)
  * http:
    + parse errors are now reported when NODE_DEBUG=http (#13206)
    + Agent constructor can now be invoked without new (#12927)
  * zlib: node will now throw an Error when zlib rejects the value
    of windowBits, instead of crashing (#13098)
- Drop 0f3e69db.patch: fixed upstream
* Wed Aug  2 2017 adam.majer@suse.de
- Fix update-alternative handling in %%postun - don't remove
  links on upgrades.
* Wed Jul 12 2017 adam.majer@suse.de
- New upstream LTS release 6.11.1
  * v8: disable V8 snapshots. The hashseed embedded in the snapshot
    is currently the same for all runs of the binary. This opens
    node up to collision attacks which could result in a Denial
    of Service. We have temporarily disabled snapshots until a more
    robust solution is found. (bnc#1048299, CVE-2017-11499)
  * The c-ares function ares_parse_naptr_reply(), which is used for
    parsing NAPTR responses, could be triggered to read memory
    outside of the given input buffer if the passed in DNS response
    packet was crafted in a particular way.
    (CVE-2017-1000381, bnc#1044946)
* Fri Jul  7 2017 adam.majer@suse.de
- Depend on nodejs-common that is then used to pick correctly
  versioned node or npm binary. This is required since 3rd party
  modules use `/usr/bin/env node` which breaks if multiple versions
  of NodeJS are installed at the same time and non-default version
  is used (for example, to compile a native module)
* Thu Jul  6 2017 adam.majer@suse.de
- npm_search_paths.patch: Since concurrent installations are now
  possible, node manual pages are moved once again back under npm
  searcheable locations only.
- versioned.patch: All files are now under versioned directoies
  and names. node and npm symlinks are now managed by
  update-alternatives
- node-gyp-addon-gypi.patch: Reference versioned directories only
* Tue Jun 13 2017 adam.majer@suse.de
- New upstream LTS release 6.11.0
  * added support for building mips64el
  * cluster:
    + disconnect() now returns a reference to the disconnected
    worker.
  * crypto:
    + ability to select cert store at runtime
    + Use system CAs instead of using bundled ones
    (obsoletes 8334.diff)
    + The Decipher methods setAuthTag() and setAAD now return this
    + adding support for OPENSSL_CONF again
    + make LazyTransform compabile with Streams1
  * deps:
    + upgrade libuv to 1.11.0
  * dns:
    + Implemented {ttl: true} for resolve4() and resolve6().
  * process:
    + add NODE_NO_WARNINGS environment variable
  * readline:
    + add option to stop duplicates in history
  * src:
    + support "--" after "-e" as end-of-options
  * tls:
    + new tls.TLSSocket() supports sec ctx options
    + Allow obvious key/passphrase combinations.
- Fix typo in node-gyp-addon-gypi.patch patch
- Refresh icu59.patch
* Tue May 30 2017 adam.majer@suse.de
- 0f3e69db.patch, icu59.patch: backported GCC 7 compilation fixes
  for v8 backported and add missing ICU59 includes (bnc#1041282)
* Tue May 23 2017 adam.majer@suse.de
- New upstream LTS release 6.10.3
  * b8:
    + Trigger OOM crash on memory allcation errors
    + Don't treat catch scopes as possibly-shadowing for sloppy eval
  * lib: fix event race condition with -e
  * src: fix base64 decoding in rare edgecase
  * tls:
    + fix segfault on destroy after partial read
    + keep track of stream that is closed
    + fix macro to check NPN feature
- nodejs-libpath.patch: updated
* Wed Apr  5 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.10.2
  * crypto: fix memory leak if certificate is revoked (#12089)
  * deps: backport V8 fixes for spread syntax regression
    causing segfaults (#12037)
- Changes not applicable to openSUSE in 6.10.2:
  * deps: upgrade zlib to 1.2.11 (#10980)
  * repl: revert commit that broke REPL display on Windows (#12123)
- Changes in LTS release 6.10.1
  * performance: The performance of several APIs has been improved.
    + Buffer.compare() is up to 35%% faster on average.
    + buffer.toJSON() is up to 2859%% faster on average.
    + fs.*statSync() functions are now up to 9%% faster on average.
    + os.loadavg is up to 151%% faster.
    + process.memoryUsage() is up to 34%% faster.
    + querystring.unescape() for Buffers is 15%% faster on average.
    + querystring.stringify() is up to 7.8%% faster on average.
    + querystring.parse() is up to 21%% faster on average.
  * IPC: Batched writes have been enabled for process IPC on
    platforms that support Unix Domain Sockets. Performance gains
    may be up to 40%% for some workloads.
  * child_process: spawnSync now returns a null status when child
    is terminated by a signal. This fixes the behavior to act like
    spawn() does.
  * http: Control characters are now always rejected when using
    http.request(). Debug messages have been added for cases when
    headers contain invalid values.
  * node: Heap statistics now support values larger than 4GB.
  * timers: Timer callbacks now always maintain order when
    interacting with domain error handling.
* Sun Feb 26 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.10.0
  * crypto: allow adding extra certs to well-known CAs
  * deps: upgrade INTL ICU to version 58
  * fs: cache non-symlinks in realpathSync
  * process: add process.memoryUsage().external
  * repl: allow autocompletion for scoped packages
  * src: add wrapper for process.emitWarning()
- Modify 8334.diff:
  * Remove merged reference counting code (#9409)
  * Bring patch in line with upstream changes (#8334)
* Fri Feb  3 2017 adam.majer@suse.de
- New upstream LTS release 6.9.5
  * deps: upgrade openssl sources to 1.0.2k
    (CVE-2017-3731, CVE-2017-3732, CVE-2016-7055,
    bnc#1022085, bnc#1022086, bnc#1009528)
- No changes in LTS release 6.9.4
- Adjusted 8334.diff to be inline with accepted changes
* Fri Jan  6 2017 qantas94heavy@gmail.com
- Add basic check that Node.js loads successfully to spec file
* Wed Jan  4 2017 qantas94heavy@gmail.com
- New upstream LTS release 6.9.3
  * build: shared library support is now working for AIX builds
  * deps/npm: upgrade npm to 3.10.10
  * deps/V8: destructuring of arrow function arguments via computed
    property no longer throws
  * inspector: /json/version returns object, not an object wrapped
    in an array
  * module: using --debug-brk and --eval together now works
    as expected
  * process: improve performance of nextTick up to 20%%
  * repl: the division operator will no longer be accidentally
    parsed as regex
  * repl: improved support for generator functions
  * timers: recanceling a cancelled timers will no longer throw
* Fri Dec  9 2016 qantas94heavy@gmail.com
- New upstream LTS version 6.9.2
  * buffer: coerce slice parameters consistently
  * deps/npm: upgrade npm to 3.10.9
  * deps/V8: Various fixes to destructuring edge cases
    + cherry-pick 3c39bac from V8 upstream
    + cherry pick 7166503 from upstream v8
  * gtest: the test reporter now outputs tap comments as yamlish
  * inspector: inspector now prompts user to use 127.0.0.1 rather
    than localhost
  * tls: fix memory leak when writing data to TLSWrap instance
    during handshake
- Modify 8334.diff:
  * ported and updated system CA store for the new node crypto code
* Wed Nov 23 2016 adam.majer@suse.de
- Add missing conflicts to base package. It's not possible to have
  concurrent nodejs installations.
* Fri Nov 18 2016 adam.majer@suse.de
- Package unification across various branches of NodeJS. Package
  for 4.x, 6.x and current (7.x) branches of NodeJS are now
  handled via GitHub repository.
- NodeJS 6.x LTS package, based on NodeJS 4.x LTS layout. All
  NodeJS packages are interchangeable. (FATE #321373)
* Mon Nov  7 2016 adam.majer@suse.de
- Add versioned dependencies for unbundling of c-ares and icu
  libraries
- SLE12 can have unbundled libicu
* Wed Nov  2 2016 qantas94heavy@gmail.com
- Fork package devel:languages:nodejs/nodejs
- Remove support-arm64-build.patch (not necessary for aarch64 build)
- Use system library versions of c-ares and ICU where supported
- Remove /usr/{lib,lib64}/node_modules from global module paths
  * This is deprecated behaviour that was caused by an incorrect patch
    in devel:languages:nodejs/nodejs almost 6 months ago (boo#985350)
- Modify nodejs-libpath.patch
  * Move /usr/lib64/node_modules to %%{_libexecpath} as npm isn't
    architecture dependent (only npm itself is stored there)
- Remove nodejs-libpath64.patch
- Use separate .sig file instead of .asc file for source verification
- Use exec instead of xargs to remove files in install script
